@@ -29,7 +29,7 @@ func TestCleanImage(t *testing.T) {
 	}
 
 	for _, table := range tables {
-		imageOut := cleanImage(table.imageIn)
+		imageOut := cleanImage(context.Background(), table.imageIn)
 		assert.Equal(t, table.imageOut, imageOut)
 	}
 }
